### Name: plspm
### Title: PLS-PM: Partial Least Squares Path Modeling
### Aliases: plspm


### ** Examples

  ## Not run: 
##D   ## example of PLS-PM in ecological analysis
##D   ## model with three LVs and formative indicators
##D   data(arizona)
##D   ari.mat <- matrix(c(0,0,0,0,0,0,1,1,0),3,3,byrow=TRUE)
##D   dimnames(ari.mat) <- list(c("ENV","SOIL","DIV"),c("ENV","SOIL","DIV"))
##D   ari.sets <- list(c(1,2),c(3,4,5),c(6,7,8)) 
##D   ari.mod <- c("B","B","B")  ## formative indicators
##D   res1 <- plspm(arizona, inner.mat=ari.mat, sets=ari.sets, modes=ari.mod,
##D   scheme="factor", scaled=TRUE, plsr=TRUE)
##D   res1
##D   summary(res1)
##D   
##D   ## typical example of PLS-PM in customer satisfaction analysis
##D   ## model with six LVs and reflective indicators
##D   data(satisfaction)
##D   IMAG <- c(0,0,0,0,0,0)
##D   EXPE <- c(1,0,0,0,0,0)
##D   QUAL <- c(0,1,0,0,0,0)
##D   VAL  <- c(0,1,1,0,0,0)
##D   SAT  <- c(1,1,1,1,0,0) 
##D   LOY  <- c(1,0,0,0,1,0)
##D   sat.mat <- rbind(IMAG, EXPE, QUAL, VAL, SAT, LOY)
##D   sat.sets <- list(1:5,6:10,11:15,16:19,20:23,24:27)
##D   sat.mod <- rep("A",6)   ## reflective indicators
##D   res2 <- plspm(satisfaction, sat.mat, sat.sets, sat.mod, scheme="centroid", 
##D                 scaled=FALSE)
##D   summary(res2)
##D   
##D   ## example of PLS-PM in sensory analysis
##D   ## estimate a path model for the orange juice data
##D   data(orange)
##D   senso.mat <- matrix(c(0,0,0,1,0,0,1,1,0),3,3,byrow=TRUE)
##D   dimnames(senso.mat) <- list(c("PHYCHEM","SENSORY","HEDONIC"),
##D                               c("PHYCHEM","SENSORY","HEDONIC"))
##D   senso.sets <- list(1:9,10:16,17:112)
##D   senso.mod <- rep("A",3)
##D   res3 <- plspm(orange, senso.mat, senso.sets, senso.mod, 
##D                 scheme="centroid", scaled=TRUE, boot.val=FALSE)
##D 
##D   ## example of PLS-PM in multi-block data analysis
##D   ## estimate a path model for the wine data set 
##D   ## requires package FactoMineR 
##D   library(FactoMineR)
##D   data(wine)
##D   SMELL <- c(0,0,0,0)
##D   VIEW <- c(1,0,0,0)
##D   SHAKE <- c(1,1,0,0)
##D   TASTE <- c(1,1,1,0)
##D   wine.mat <- rbind(SMELL,VIEW,SHAKE,TASTE)
##D   wine.sets <- list(3:7,8:10,11:20,21:29)
##D   wine.mods <- rep("A",4)
##D   scheme <- "centroid"
##D   scaled <- FALSE
##D   boot.val <- FALSE
##D   res4 <- plspm(wine, wine.mat, wine.sets, wine.mods, scheme="centroid")                
##D   
## End(Not run)



